@@ -1,10 +1,12 @@
 setOldClass("igraph")
+setClassUnion("array_Or_matrix", members = c("array", "matrix"))
 
-#' @title GraphSpace: An S4 class for PathwaySpace graphics
+#' @title GraphSpace: An S4 class for igraph objects
 #'
 #' @slot nodes A data frame with xy-vertex coordinates.
 #' @slot edges  A data frame with edges.
 #' @slot graph An igraph object.
+#' @slot image An image matrix or array object.
 #' @slot pars A list with parameters.
 #' @slot misc A list with intermediate objects for downstream methods.
 #'
@@ -23,6 +25,7 @@ setClass("GraphSpace",
         nodes = "data.frame",
         edges = "data.frame",
         graph = "igraph",
+        image = "array_Or_matrix",
         pars = "list",
         misc = "list"
     ),
@@ -30,6 +33,7 @@ setClass("GraphSpace",
         nodes = data.frame(),
         edges = data.frame(),
         graph = igraph::empty_graph(),
+        image = array(),
         pars = list(),
         misc = list()
     )
